==> sword-1.1.0.tgz: sword/sword.cpp <==
#include <stdio.h>
#include <iostream.h>
#include <versekey.h>
#include <rawtext.h>
#include <zcom.h>
#include <rawcom.h>
#include <rawgbf.h>
#include <stdlib.h>

int main(int argc, char **argv)
{
	int loop;
	int max;
//	RawText webster("modules/texts/rawtext/sve/", "Sven Text", "Sven Text");
//	RawText webster("modules/texts/rawtext/webster/", "Webster", "Webster Text");
//	RawText webster("modules/texts/rawtext/orthjbc/", "Webster", "Webster Text");
//	RawGBF webster("modules/texts/rawgbf/web/", "WEB", "World English Bible");
//	RawText webster("modules/texts/rawtext/kjv/", "KJV", "KJV Text");
	RawText webster("modules/texts/rawtext/vnt/", "VNT", "Valera Spanish NT");
	RawCom  mhc("modules/comments/rawcom/rwp/", "RWP", "Robertson's Word Pictures");
//	zCom  mhc("modules/comments/zcom/mhc/", "MHC", "Matthew Henry's Commentary on the Whole Bible");
	VerseKey mykey;

	if (argc > 3)
		mykey.AutoNormalize(0);  // Turn off autonormalize if 3 args to allow for intros
				// This is kludgy but at lease you can try it
				// with something like: sword "Matthew 1:0" 1 1

	mykey = (argc < 2) ? "James    1:19" : argv[1];
	mykey.Persist(1);
	webster.SetKey(mykey);
	mhc.SetKey(mykey);

	max = (argc < 3) ? 1 : atoi(argv[2]);

	cout << "\n";

	for (loop = 0; loop < max; loop++) {
		cout << (SWKey)webster << ":\n";
		webster.Display();
		cout << "\n";
		cout << "-------------\n";
//		mhc.Display();
//		cout << "\n";
//		cout << "==========================\n";
		mykey++;
	}
	cout << "\n\n";
}

==> sword-1.1.2.tgz: sword/sword.cpp <==
#include <stdio.h>
#include <iostream.h>
#include <versekey.h>
#include <rawtext.h>
#include <zcom.h>
#include <rawcom.h>
#include <rawgbf.h>
#include <stdlib.h>

int main(int argc, char **argv)
{
	int loop;
	int max;
//	RawText webster("modules/texts/rawtext/sve/", "Sven Text", "Sven Text");
//	RawText webster("modules/texts/rawtext/webster/", "Webster", "Webster Text");
//	RawText webster("modules/texts/rawtext/orthjbc/", "Webster", "Webster Text");
	RawGBF webster("modules/texts/rawgbf/web/", "WEB", "World English Bible");
//	RawText webster("modules/texts/rawtext/kjv/", "KJV", "KJV Text");
//	RawText webster("modules/texts/rawtext/vnt/", "VNT", "Valera Spanish NT");
//	RawCom  mhc("modules/comments/rawcom/rwp/", "RWP", "Robertson's Word Pictures");
	RawCom  mhc("modules/comments/rawcom/mhc/", "MHC", "Matthew Henry's Commentary on the Whole Bible");
	VerseKey mykey;

	if (argc > 3)
		mykey.AutoNormalize(0);  // Turn off autonormalize if 3 args to allow for intros
				// This is kludgy but at lease you can try it
				// with something like: sword "Matthew 1:0" 1 1

	mykey = (argc < 2) ? "James    1:19" : argv[1];
	mykey.Persist(1);
	webster.SetKey(mykey);
	mhc.SetKey(mykey);

	max = (argc < 3) ? 1 : atoi(argv[2]);

	cout << "\n";

	for (loop = 0; loop < max; loop++) {
		cout << (SWKey)webster << ":\n";
		webster.Display();
		cout << "\n";
		cout << "-------------\n";
//		mhc.Display();
//		cout << "\n";
//		cout << "==========================\n";
		mykey++;
	}
	cout << "\n\n";
}
